==> gimp-2.9.2.tar.bz2: gimp-2.9.2/app/tools/gimpthresholdtool.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_THRESHOLD_TOOL_H__
#define __GIMP_THRESHOLD_TOOL_H__


#include "gimpimagemaptool.h"


#define GIMP_TYPE_THRESHOLD_TOOL            (gimp_threshold_tool_get_type ())
#define GIMP_THRESHOLD_TOOL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_THRESHOLD_TOOL, GimpThresholdTool))
#define GIMP_THRESHOLD_TOOL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_THRESHOLD_TOOL, GimpThresholdToolClass))
#define GIMP_IS_THRESHOLD_TOOL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_THRESHOLD_TOOL))
#define GIMP_IS_THRESHOLD_TOOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_THRESHOLD_TOOL))
#define GIMP_THRESHOLD_TOOL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_THRESHOLD_TOOL, GimpThresholdToolClass))


typedef struct _GimpThresholdTool      GimpThresholdTool;
typedef struct _GimpThresholdToolClass GimpThresholdToolClass;

struct _GimpThresholdTool
{
  GimpImageMapTool     parent_instance;

  GimpThresholdConfig *config;

  /*  dialog  */
  GimpHistogram       *histogram;
  GimpHistogramBox    *histogram_box;
};

struct _GimpThresholdToolClass
{
  GimpImageMapToolClass  parent_class;
};


void    gimp_threshold_tool_register (GimpToolRegisterCallback  callback,
                                      gpointer                  data);

GType   gimp_threshold_tool_get_type (void) G_GNUC_CONST;


#endif  /*  __GIMP_THRESHOLD_TOOL_H__  */

==> gimp-2.9.4.tar.bz2: gimp-2.9.4/app/tools/gimpthresholdtool.h <==
/* GIMP - The GNU Image Manipulation Program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_THRESHOLD_TOOL_H__
#define __GIMP_THRESHOLD_TOOL_H__


#include "gimpfiltertool.h"


#define GIMP_TYPE_THRESHOLD_TOOL            (gimp_threshold_tool_get_type ())
#define GIMP_THRESHOLD_TOOL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_THRESHOLD_TOOL, GimpThresholdTool))
#define GIMP_THRESHOLD_TOOL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_THRESHOLD_TOOL, GimpThresholdToolClass))
#define GIMP_IS_THRESHOLD_TOOL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_THRESHOLD_TOOL))
#define GIMP_IS_THRESHOLD_TOOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_THRESHOLD_TOOL))
#define GIMP_THRESHOLD_TOOL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_THRESHOLD_TOOL, GimpThresholdToolClass))


typedef struct _GimpThresholdTool      GimpThresholdTool;
typedef struct _GimpThresholdToolClass GimpThresholdToolClass;

struct _GimpThresholdTool
{
  GimpFilterTool    parent_instance;

  /*  dialog  */
  GimpHistogram    *histogram;
  GimpHistogramBox *histogram_box;
};

struct _GimpThresholdToolClass
{
  GimpFilterToolClass  parent_class;
};


void    gimp_threshold_tool_register (GimpToolRegisterCallback  callback,
                                      gpointer                  data);

GType   gimp_threshold_tool_get_type (void) G_GNUC_CONST;


#endif  /*  __GIMP_THRESHOLD_TOOL_H__  */
